
# Project description

NTK is set of widgets and utils that implement high-level APIs for accessing many aspects of modern desktop systems. These include database management with orm, widgets like js components, as well as desktop UI development in less code.

NTK is a comprehensive set of Python bindings for tkinter and ttk. It is a comprehensive and easy to use GUI library for python. It lets you create attractive design in a quick and convenient way. 

It also comes with a dynamic ORM that lets you easily create update and delete your fully functioning database system. It’s also packed with high quality widgets with a variety of choices that can be easily configured to your application.


# Installation
The latest version of ntk can be installed from PyPI:

    pip install ntk


# Quick use
Copy code from below and paste into a python file, then see the magic difference between base tkinter and ntk

    from ntk import Tk

    def main():
        root = Tk()
        root.mainloop()

    if __name__=='__main__':
        main()


# Documentation
The documentation for the latest release can be found in [NTK Documentation](https://ntk.readthedocs.io)


# Author
NTK is a open source libraries for Python, Initially developed by Nj Nafir, Everyones can contribute to build NTK as friendly and handy library.


# Contribute
- Issue Tracker: [NTK Issues](https://github.com/njNafir/ntk/issues)
- Source Code: [NTK Sources](https://github.com/njNafir/ntk)


# Support

If you are having issues, please let us know.
We have a mailing list located at: njnafir@gmail.com


# License
The project is licensed under the MIT license.
